==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/de.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Aktivitäten",
    "Error loading activities" : "Fehler beim Laden der Aktivitäten",
    "No activities" : "Keine Aktivitäten",
    "Load more activities" : "Weitere Aktivitäten laden",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "Zum Kopieren ⌘-C drücken.",
    "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
    "{name} (invisible)" : "{name} (unsichtbar)",
    "{name} (restricted)" : "{name} (eingeschränkt)",
    "in {path}" : "in {path}",
    "This stream will show events like additions, changes & shares" : "Dieser Stream zeigt Ereignisse wie Hinzugekommenes, Änderungen und Freigaben an",
    "There are no events for this filter" : "Keine Ereignisse für diesen Filter vorhanden",
    "Today" : "Heute",
    "Yesterday" : "Gestern",
    "Activity" : "Aktivität",
    "Personal activity feed for %s" : "Persönlicher Feed der Aktivitäten für %s",
    "Your feed URL is invalid" : "Deine Feed-URL ist ungültig",
    "Your settings have been updated." : "Deine Einstellungen wurden aktualisiert.",
    "Mail" : "E-Mail",
    "Stream" : "Stream",
    "All activities" : "Alle Aktivitäten",
    "By others" : "Von anderen",
    "By you" : "Von Dir",
    "\"remote user\"" : "„Externer Benutzer“",
    "Activity notification" : "Benachrichtigung über die Aktivitäten",
    ", " : ", ",
    "%s and %s" : "%s und %s",
    "Hello %s," : "Hallo %s,",
    "You are receiving this email because the following things happened at %s" : "Du erhältst diese E-Mail, da folgende Dinge auf %s geschehen sind",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* und %n weiterer","* und %n weitere"],
    "List your own actions in the stream" : "Deine eigenen Aktivitäten im Stream auflisten",
    "Notify about your own actions via email" : "Über Deine eigenen Aktivitäten via E-Mail benachrichtigen",
    "You need to set up your email address before you can receive notification emails." : "Bevor Du E-Mail-Benachrichtigungen empfangen kannst, musst Du Deine E-Mail-Adresse einrichten.",
    "Send emails:" : "Sende E-Mails:",
    "Hourly" : "Stündlich",
    "Daily" : "Täglich",
    "Weekly" : "Wöchentlich",
    "Activity feed" : "Feed der Aktivitäten",
    "Enable RSS feed" : "RSS-Feed aktivieren",
    "No activity yet" : "Bislang keine Aktivitäten",
    "No more events to load" : "Keine weiteren Ereignisse zum Laden",
    "Files" : "Dateien"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/de.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Aktivitäten",
    "An error occurred while loading activities" : "Es ist ein Fehler beim Laden der Aktivitäten aufgetreten",
    "No activity yet" : "Bislang keine Aktivitäten",
    "Load more activities" : "Weitere Aktivitäten laden",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "Zum Kopieren ⌘-C drücken.",
    "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
    "{name} (invisible)" : "{name} (unsichtbar)",
    "{name} (restricted)" : "{name} (eingeschränkt)",
    "in {path}" : "in {path}",
    "This stream will show events like additions, changes & shares" : "Dieser Stream zeigt Ereignisse wie Hinzugekommenes, Änderungen und Freigaben an",
    "There are no events for this filter" : "Keine Ereignisse für diesen Filter vorhanden",
    "Today" : "Heute",
    "Yesterday" : "Gestern",
    "Personal activity feed for %s" : "Persönlicher Feed der Aktivitäten für %s",
    "Your feed URL is invalid" : "Deine Feed-URL ist ungültig",
    "Your settings have been updated." : "Deine Einstellungen wurden aktualisiert.",
    "Settings have been updated." : "Die Einstellungen wurden aktualisiert.",
    "Mail" : "E-Mail",
    "Stream" : "Stream",
    "All activities" : "Alle Aktivitäten",
    "By others" : "Von anderen",
    "By you" : "Von Dir",
    "\"remote user\"" : "„Externer Benutzer“",
    "Hello %s" : "Hallo %s",
    "Hello %s," : "Hallo %s,",
    "There was some activity at %s" : "Es gab Aktivitäten bei %s",
    "_and %n more _::_and %n more _" : ["und %n weiterer","und %n weitere"],
    "Activity notification" : "Benachrichtigung über die Aktivitäten",
    ", " : ", ",
    "%s and %s" : "%s und %s",
    "Activity" : "Aktivität",
    "Activity feed" : "Feed der Aktivitäten",
    "Configure the default activity settings for new users." : "Nehme die Voreinstellungen der Aktivitäten für neue Benutzer vor.",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Wähle für welche Aktivitäten E-Mails empfangen und welche Aktivitäten in Deinem Feed angezeigt werden.",
    "List your own actions in the stream" : "Deine eigenen Aktivitäten im Stream auflisten",
    "Notify about your own actions via email" : "Über Deine eigenen Aktivitäten via E-Mail benachrichtigen",
    "You need to set up your email address before you can receive notification emails." : "Bevor Du E-Mail-Benachrichtigungen empfangen kannst, musst Du Deine E-Mail-Adresse einrichten.",
    "Send emails:" : "Sende E-Mails:",
    "Hourly" : "Stündlich",
    "Daily" : "Täglich",
    "Weekly" : "Wöchentlich",
    "Settings" : "Einstellungen",
    "Enable RSS feed" : "RSS-Feed aktivieren",
    "No more events to load" : "Keine weiteren Ereignisse zu laden",
    "Files" : "Dateien",
    "Error loading activities" : "Fehler beim Laden der Aktivitäten",
    "No activities" : "Keine Aktivitäten",
    "You are receiving this email because the following things happened at %s" : "Du erhältst diese E-Mail, da folgende Dinge auf %s geschehen sind",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* und %n weitere","* und %n weitere"]
},
"nplurals=2; plural=(n != 1);");
